Cave Story (Troubleshooting)

- Troubleshooting -
The following are possible issues that may occur while playing the game.
If you run across problems not listed here, feel free to contact the author via email or on Studio Pixel's message board.
(Translator's note: Studio Pixel is not responsible for errors and problems related to the AGTP English translation patch.
If you have problems related to the translation, kindly email the AGTP at aeongen@gmail.com or post a message on the Pantheon at http://agtp.romhack.net/.)
* I get an error message saying, "Cannot read generic file."
(Translator's note: Error messages may appear in Japanese.)
- Try redownloading the game.
The files may have been corrupted.
- Try using a different uncompression program.
Some uncompression software may alter the directory structure so that the program is unable to find certain files.
* The game runs extremely slowly.
- Try changing the screen mode in DoConfig.exe.
There shouldn't be any problems if your computer is fast enough,
but the most appropriate screen mode can vary depending on the computer.
(Full-screen is recommended.)
- Try changing the "color quality" in your Display Properties.
Depending on your computer, the number of colors displayed can significantly affect the game speed.
24-bit or 32-bit color is recommended.
- Try adjusting your DirectX settings.
You can adjust DirectX settings using the diagnostic tool "dxdiag.exe".
Select "Run..." from the Start Menu and enter "dxdiag".
For detailed instructions on how to use the tool, consult the program's "Help" function.
- Try adjusting your hardware acceleration.
You can change the settings of your hardware acceleration
by opening Display Properties -> Settings -> Advanced and selecting the "Troubleshoot" or "Performance" tag.
- Try updating your drivers.
Some problems may be resolved if you update your graphics drivers.
* The background music cuts off.
- Try adjusting your audio hardware acceleration.
You may be able to fix this problem by adjusting the hardware acceleration for your sound card.
Open Control Panel -> Sounds and Audio Devices -> Audio -> Advanced -> Performance.
* When I press two keys on the keyboard at once, only one registers.
- Change the keys in DoConfig.exe.
Some keyboards fail to register the down-arrow key if "Z" and the right-arrow key are pressed.
If this is the case, please play using the "< > /" setting.
* When playing with a gamepad, the main character moves in directions that aren't being pressed.
- Please restart the game without any buttons on the gamepad being pressed.
If you start the game while holding a directional button,
the game will have problems recognizing directional input after that.
* Saving doesn't work.
- Save data is stored in the file "Profile.dat", created in the same directory as Doukutsu.exe.
If this file cannot be written to, saving will not be possible.
Check that "Profile.dat" is not set to "Read-only" and that the game is not being run from a read-only drive.
* Running in 256-color mode
- This game was created assuming an operating environment with 16-bit color or higher.
Playing with only 256 colors will result in abrupt color shifts and missing portions of some pictures, among other problems.
I have no plans to correct this.
* The "error" file
If certain errors cause the game to quit, a file labeled "error" will sometimes be created in the same directory
as the executable (Doukutsu.exe). This file can be deleted safely.